irates.ratio. By default it prints all competing events incidence rates contained in irates. It is also possible to select specific events to be printed.
"print"(x, event.code = NULL, display.digits = 4, ...)irates.ratio object
irates.ratio shall be printed. If NULL, event.code will be inherited from irates.ratio
irates.ratio